Core Module
===========

.. automodule:: cvd_risk.core
   :members:
   :undoc-members:
   :show-inheritance:

Base Classes
------------

.. autoclass:: cvd_risk.core.base.RiskModel
   :members:
   :special-members:

Validation Models
----------------

.. autoclass:: cvd_risk.core.validation.PatientData
   :members:
   :special-members:

.. autoclass:: cvd_risk.core.validation.RiskResult
   :members:
   :special-members:

